/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, {useContext, useState, useEffect} from 'react';
import { Button } from '@material-ui/core';
import Modal from '@material-ui/core/Modal';
import Backdrop from '@material-ui/core/Backdrop';
import Zoom from '@material-ui/core/Fade';
import styled from 'styled-components'
import LoginContainer from './LoginContainerFunction.js'
import {Store} from '../Store.js'
import axios from 'axios'
import {apiUrl} from '../env';
import Snackbar from '@material-ui/core/Snackbar';
import MuiAlert from '@material-ui/lab/Alert';



function Alert(props) {
  return <MuiAlert elevation={6} variant="filled" {...props} />;
}

export default function LoginComponent (props) {
    const {state, dispatch} = useContext(Store)

    /*snackbar variables*/
    const [successSnackbar, toggleSuccessSnackbar] = useState(false)
    const [failSnackbar, toggleFailSnackbar] = useState(false)


    useEffect( () => {
        if(state.currentUser.id === '') {
            const email = sessionStorage.getItem('@portalmec/uid')
            const password = sessionStorage.getItem('@portalmec/senha')

            let loginInfo = {email : email, senha : password}
            tryLogin(loginInfo)
        }
    }, [])

    const tryLogin = (login) => {
        axios.post(`${apiUrl}/auth/sign_in`,
            {
            email : login.email,
            password : login.senha
        }).then( (response) => {
                console.log(response)
                handleSuccess(response, login.senha)
            },
            (error) => {
                handleFailure()
            }
        )
    }

    const handleSuccess = (response, senha) => {
        toggleSuccessSnackbar(true)
        dispatch ({
            type: "USER_LOGGED_IN",
            userLoggedIn: !state.userIsLoggedIn,
            login: {
                id : response.data.data.id,
                username : response.data.data.name,
                email : response.data.data.email,
                accessToken : response.headers['access-token'],
                clientToken : response.headers.client,
                userAvatar : response.data.data.avatar_file_name,
                userCover : response.data.data.cover_file_name,
                uid : response.data.data.uid,
                followCount : response.data.data.follows_count,
                collectionsCount : response.data.data.collections_count,
                submitter_request : response.data.data.submitter_request
                }
            }
        )
        sessionStorage.setItem('@portalmec/accessToken', response.headers['access-token'])
        sessionStorage.setItem('@portalmec/clientToken', response.headers.client)
        sessionStorage.setItem('@portalmec/id', response.data.data.id)
        sessionStorage.setItem('@portalmec/username', response.data.data.name)
        sessionStorage.setItem('@portalmec/uid', response.data.data.uid)
        sessionStorage.setItem('@portalmec/senha', senha)
        props.handleClose()
    }

    const handleFailure = () => {
        toggleFailSnackbar(false)
    }

    return (
        <>
        {/*failure snackbar-----------------------------------------------------------------*/}
            <Snackbar open={failSnackbar} autoHideDuration={1000} onClose={() => {toggleFailSnackbar(false)}}
            anchorOrigin = {{ vertical:'top', horizontal:'right' }}
            >
                <Alert severity="error">Ocorreu um erro ao se conectar!</Alert>
            </Snackbar>
        {/*---------------------------------------------------------------------------------*/}

        {/*success snackbar-----------------------------------------------------------------*/}
            <Snackbar open={successSnackbar} autoHideDuration={1000}
            onClose={() => {toggleSuccessSnackbar(false)}} anchorOrigin = {{ vertical:'top', horizontal:'middle' }}
            >
                <Alert severity="success" style={{backgroundColor:"#00acc1"}}>Você está conectado(a)!</Alert>
            </Snackbar>
        {/*---------------------------------------------------------------------------------*/}


        <StyledLogin
            aria-labelledby="transition-modal-title"
            aria-describedby="transition-modal-description"
            open={props.open}
            animation={true}
            centered={true}
            onClose={props.handleClose}
            closeAfterTransition
            BackdropComponent={Backdrop}
            BackdropProps={{
                timeout: 500,
            }}
         >
            <Zoom in={props.open} style={{ transitionDelay :"0.2ms"}}>
                <LoginContainer
                    handleClose={props.handleClose}
                    openSignUp={props.openSignUp}
                    handleLoginInfo={tryLogin}
                />
            </Zoom>
        </StyledLogin>
        </>
    )

}
const StyledLogin = styled(Modal)`
    margin : 0 !important;
    margin-left : 0 !important;
    display : flex;
    align-items: center;
    justify-content : center;
    text-align : center;
    padding : 10px !important;
    border-radius : 4px;

`
