import React, {useContext} from 'react';
import Modal from '@material-ui/core/Modal';
import Fade from '@material-ui/core/Fade';
import styled from 'styled-components'
import { Button } from '@material-ui/core';
import Backdrop from '@material-ui/core/Backdrop';
import { Store } from '../Store.js';
import axios from 'axios'
import {apiUrl} from '../env';
import CloseIcon from '@material-ui/icons/Close';

const StyledModal = styled(Modal)`
    margin : 0 !important;
    margin-left : 0 !important;
    display : flex;
    align-items: center;
    justify-content : center;
    text-align : center;
    padding : 10px !important;
    border-radius : 4px;
    max-width : none;
    max-height : none;
    min-width: 1500px;
    min-height: 150px !important;
`

const HeaderDiv = styled.div`
    max-width : 100%;
    display : flex;
    align-items : center;
    align-content : center;
`
const ContentContainer = styled.div`
    width : 30%;
    box-sizing : border-box;
    background-color : white;
    max-width : none;
    align : center;
    border-radius : 4px;
    font-family : 'Roboto', sans serif;
`
const ButtonCancelar = styled(Button)`
    &:hover {
        background-color : rgba(158,158,158,0.2) !important;
    }
    background-color : #fff !important;
    color : #666 !important;
    text-decoration : none !important;
    outline : none !important;
    text-align : center !important;
`

const ButtonConfirmar = styled(Button)`
    background-color : #00bcd4 !important;
    color : #fff !important;
    border-radius : 3px !important;
`

export default function IllegalContentModal (props) {
    const text = {
        header : "Tem certeza que deseja deixar de seguir este usuário?",
        explanation : "Este usuário deixará de fazer parte da sua rede."
    }

    return (
        <StyledModal
        aria-labelledby="transition-modal-title"
        aria-describedby="transition-modal-description"
        open={props.open}
        animation={true}
        centered={true}
        onClose={props.handleClose}
        closeAfterTransition
        BackdropComponent={Backdrop}
        BackdropProps={{
            timeout: 500,
        }}
        >
            <Fade in={props.open}>
                <ContentContainer>
                    <HeaderDiv>
                        <span style={{width:"32px"}}/>
                        <h3 style={{fontSize : "24px", marginTop:"20px", marginBottom:"10px", fontWeight : "normal"}}>
                            {text.header}
                        </h3>
                        <Button style={{marginRight:"0", color:"000"}} onClick={props.handleClose}>
                            <CloseIcon style={{color:"#666", cursor:"pointer", verticalAlign:"middle"}}/>
                        </Button>
                    </HeaderDiv>
                    <div style={{display : "flex", flexDirection : "column", padding : "20px 30px"}}>
                        <div style={{marginTop : "0", textAlign : "center", marginBottom : "20px"}}>
                            <span style={{fontSize : "14px", color : "#666"}}>{text.explanation}</span>
                        </div>
                        <div style={{display : "flex", flexDirection : "row", justifyContent: "space-evenly"}}>
                            <ButtonCancelar onClick={props.handleClose}>CANCELAR</ButtonCancelar>
                            <ButtonConfirmar onClick={props.handleConfirm}>DEIXAR DE SEGUIR </ButtonConfirmar>
                        </div>
                    </div>
                </ContentContainer>
            </Fade>

        </StyledModal>
    )

}
