import React, {useState, useEffect} from 'react'
import axios from 'axios'
import {apiUrl, apiDomain} from '../../../env';
import PanelTemplateRede from '../PanelComponents/TemplateRede.js'

const getConfig = () => {
    let config = {
        headers : {
            'Accept': 'application/json',
            'Content-Type':'application/json',
            'Access-Token': sessionStorage.getItem('@portalmec/accessToken'),
            'Client': sessionStorage.getItem('@portalmec/clientToken'),
            'Uid': sessionStorage.getItem('@portalmec/uid')
        }
    }
    return config
}

export default function TabRede (props) {
    const [followers, setFollowers] = useState([])
    const [followersSlice, setFollowersSlice] = useState([])

    const showMoreFollowers = () => {
        let varSlice = followersSlice.length
        setFollowersSlice(followers.slice(0, varSlice + 4))
    }
    const showAllFollowers = () => {setFollowersSlice(followers)}

    const [following, setFollowing] = useState([])
    const [followingSlice, setFollowingSlice] = useState([])
    const showMoreFollowing = () => {
        let varSlice = followingSlice.length
        setFollowingSlice(following.slice(0, varSlice + 4))
    }
    const showAllFollowing = () => {setFollowingSlice(following)}

    useEffect( () => {
        axios.all([
            axios.get((`${apiUrl}/users/` + props.id + '/followers'), getConfig()),
            axios.get((`${apiUrl}/users/` + props.id + '/following/User'), getConfig())
        ])
        .then( (responseArr) => {
                console.log('responseArr Rede: ', responseArr)
                if (responseArr[0].headers['access-token']) {
                    sessionStorage.setItem('@portalmec/accessToken', responseArr[0].headers['access-token'])
                }
                setFollowers(responseArr[0].data)
                setFollowersSlice(responseArr[0].data.slice(0,4))

                setFollowing(responseArr[1].data)
                setFollowingSlice(responseArr[1].data.slice(0,4))
            },
            (error) => {
                console.log('error while running axios all')
            }
        )
    }, [])

    return (
        <React.Fragment>
            <PanelTemplateRede
                title={"Seguidores"}
                length={followers.length}
                sliceArr={followersSlice}
                showMore={showMoreFollowers}
                showAll={showAllFollowers}
                follower={true}
                noContentText={props.username + ' não possui nenhum seguidor'}
            />

        <PanelTemplateRede
                title={"Seguindo"}
                length={following.length}
                sliceArr={followingSlice}
                showMore={showMoreFollowing}
                showAll={showAllFollowing}
                follower={false}
                noContentText={props.username + ' não segue nenhum usuário'}
            />
        </React.Fragment>
    )
}
