import React, {useContext, useState, useEffect} from 'react'
import { Store } from '../../Store.js'
import styled from 'styled-components'
import { Container } from 'react-grid-system'
import Paper from '@material-ui/core/Paper';
import Button from '@material-ui/core/Button';
import {ContainerDivStyled} from './TabPanelMeusRecursos.js'
import {NoPubSpan, DivConteudoNaoPublicado, DivTextoNoPublications} from './TabPanelMeusRecursos.js'
import LoadingSpinner from '../LoadingSpinner.js'
import PaginaVaziaColecao from '../../img/Pagina_vazia_colecao.png'
import axios from 'axios'
import {apiUrl} from '../../env';
import LevelDescriptionCard from '../LevelDescriptionCard.js'
import AchievementDescriptionCard from '../AchievementDescriptionCard.js'
import { Grid } from '@material-ui/core'

export default function TabPanelStatusEConquistas (props) {
	const [achievements, setAchievements] = useState([]);
	const [level, setLevel] = useState(0);
	const [xp, setXP] = useState(0);
	const [coins, setCoins] = useState(0);
	const [barSize, setBarSize] = useState(0);
	const [xpToNextLevel, setXpToNextLevel] = useState(0);
	const { state } = useContext(Store)

	useEffect(() => {
		axios.all(
				['xp_to_next_lvl', 'percent_to_next_level', 'points', 'xp', 'get_level',
				'completed_achievements'].map((r) => {
					return axios.get(apiUrl + '/' + r + '?id=' + state.currentUser.id);
			})).then(axios.spread((xp_to_next_lvl, percent_to_next_level, points,
							xp, level, completed_achievements) => {
								this.setXpToNextLevel(xp_to_next_lvl);
								this.setBarSize(100-percent_to_next_level);
								this.setCoins(points);
								this.setXP(xp);
								this.setLevel(level);
								this.setAchievements(completed_achievements);
						}));
	}, [])

	return (
		<div>
		<ContainerDivStyled>
			<Paper elevation={3}>
			<LevelDescriptionCard
				xp_to_next_lvl={xpToNextLevel}
				bar_size={barSize}
				coins={coins}
				xp={xp}
				level={level}
				/>
			</Paper>
		</ContainerDivStyled>
		<AchievementsContainer>
			<AchievementsSectionTitle>
			Conquistas
			</AchievementsSectionTitle>
			<AchievementsList>
			<Grid container direction="row" justify="space-around" alignItems="center">
				{achievements.map(
					(a) => { return (
							<Grid item xs={12} md={5}>
								<AchievementDescriptionCard
									name={a.title}
									description={a.description}
									src={a.imgsrc}
									requirements={a.requirements}	/>
									//requirements={[{name: "teste", description: "teste"}]}/>
							</Grid>
						)}
				)}
			</Grid>
			</AchievementsList>
		</AchievementsContainer>
		</div>
	);
}

const AchievementsSectionTitle = styled.h1`
	font-weight: 400;
`
const AchievementsContainer = styled.div`
	max-width : 1140px;
	margin-left : auto;
	margin-right : auto;
	margin-bottom: 30px;
	margin-top: 70px;
`
const AchievementsList = styled.div`
`
