/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, {useContext, useState, useEffect} from 'react'
import axios from 'axios'
import {apiUrl} from '../../../env';
import LoadingSpinner from '../../LoadingSpinner.js'
import Template from '../PanelComponents/TemplateRecurso.js'
import PanelTemplateColecao from '../PanelComponents/TemplateColecao.js'

export default function TabPanelFavoritos (props) {
    const [loading, handleLoading] = useState(true)

    const [likedLearnObjs, setlikedLearnObjs] = useState([])
    const [likedLearnObjsSlice, setlikedLearnObjsSlice] = useState([])

    const [likedCollections, setlikedCollections] = useState([])
    const [likedCollectionsSlice, setlikedCollectionsSlice] = useState([])

    useEffect( () => {
        axios.all([
            axios.get((`${apiUrl}/users/` + props.id + '/learning_objects/liked'), props.config),
            axios.get((`${apiUrl}/users/` + props.id + '/collections/liked'), props.config),
        ])
        .then( (responseArr) => {
                console.log('responseArr favoritos: ', responseArr)
                if (responseArr[0].headers['access-token']) {
                    sessionStorage.setItem('@portalmec/accessToken', responseArr[0].headers['access-token'])
                }
                setlikedLearnObjs(responseArr[0].data)
                setlikedLearnObjsSlice(responseArr[0].data.slice(0,4))

                setlikedCollections(responseArr[1].data)
                setlikedCollectionsSlice(responseArr[1].data.slice(0,4))

                handleLoading(false)
            },
            (error) => {
                handleLoading(false)
                console.log('error while running axios all')
            }
        )
    }, [])

    const showMoreLikedLearnObj = () => {
        var sliceLength = likedLearnObjsSlice.length
        setlikedLearnObjsSlice(likedLearnObjs.slice(0, sliceLength + 4))
    }

    const showAllLikedLearnObjs = () => {setlikedLearnObjsSlice(likedLearnObjs)}

    const showMoreLikedCollections = () => {
        var sliceLength = likedCollectionsSlice.length
        setlikedCollectionsSlice(likedCollections.slice(0, sliceLength + 4))
    }

    const showAllLikedCollections = () => {setlikedCollectionsSlice(likedCollections)}

    return (
        <>
        {
            loading?
            (
                <LoadingSpinner text={'CARREGANDO...'}/>
            )
            :
            (
                [
                    <React.Fragment>
                        <Template
                            length = {likedLearnObjs.length}
                            titleText = {"Recursos Favoritados"}
                            noContentText={<p style={{fontFamily:"Roboto",fontSize:"16px"}}>Quando você favorita um recurso ele aparece nesta seção. Além disso, você
                            <br/>
                            aumenta o prestígio dele na Plataforma. Para favoritar, basta clicar no ícone de
                            <br/>
                            coração que aparece nos Recursos.
                            </p>}
                            slice={likedLearnObjsSlice}
                            showMore={showMoreLikedLearnObj}
                            showAll={showAllLikedLearnObjs}
                        />

                        <PanelTemplateColecao
                            title={"Coleções favoritadas"}
                            length={likedCollections.length}
                            noContentText={"Você ainda não curtiu nenhuma coleção."}
                            sliceArr={likedCollectionsSlice}
                            showMore={showMoreLikedCollections}
                            showAll={showAllLikedCollections}
                            followed={false}
                        />
                    </React.Fragment>
                ]
            )
        }
        </>
    )
}
