import React, {useState,useContext} from 'react'
import {Store} from '../Store.js'
import styled from 'styled-components'
import Paper from '@material-ui/core/Paper';
import PartOne from '../Components/PageProfessorComponents/PartOne.js'
import PartTwo from '../Components/PageProfessorComponents/PartTwo.js'
import PartThree from '../Components/PageProfessorComponents/PartThree.js'
import SuccessfulRequest from '../Components/PageProfessorComponents/SuccessfulRequest.js'
import ModalConfirmarProfessor from '../Components/PageProfessorComponents/ModalConfirmarProfessor.js'
import axios from 'axios'
import {apiUrl} from '../env';

export default function PageProfessor (props) {
    const {state, dispatch} = useContext(Store)
    const [modalOpen, toggleModal] = useState(false)
    const handleModal = () => {
        toggleModal(!modalOpen) ;
    }

    const redirect = () => {
        props.history.push('/termos-publicar-recurso')
    }

    const [registerInformation, setRegisterInformation] = useState(
        {
            teacher_cpf: '',
            school_phone: '',
            school_name: '',
            school_city : '',
            school_uf : {
                abbreviation : '',
                name : ''
            },
            inep_code: ''
        }
    )

    const [stepper, handleStepper] = useState(
        [ {value : '1', selected : true}, {value : '2', selected : false}, {value : '3', selected : false}, {value : '4', selected : false}]
    )
    const toggleStepper = (selected1, selected2, selected3, selected4) => {
        handleStepper(
            [
                {value : '1', selected : selected1},
                {value : '2', selected : selected2},
                {value : '3', selected : selected3},
                {value : '4', selected : selected4}
            ]
        )
    }

    const handleBuscarParteUm = (ufAbbreviation, ufName, nomeMunicipio, inep) => {
        console.log('handleBuscarParteUm: ', ufAbbreviation, ufName, nomeMunicipio, inep)
        setRegisterInformation({...registerInformation,
            school_uf : {
                abbreviation: (ufAbbreviation ? ufAbbreviation : ''),
                name : (ufName ? ufName : '')
            },
            school_city : (nomeMunicipio ? nomeMunicipio : ''),
            inep_code : (inep ? inep : '')
        })
        toggleStepper(false, true, false, false)
    }

    const handleBuscarParteDois = (city_name, inep, school_name, state_name) => {
        const uf_abbreviation = registerInformation.school_uf.abbreviation
        const prev_state_name = registerInformation.school_uf.name
        const prev_city_name = registerInformation.school_city.name

        setRegisterInformation({...registerInformation,
            school_uf : {
                abbreviation : uf_abbreviation,
                name: (state_name ? state_name : prev_state_name)
            },
            school_city :(city_name ? city_name : prev_city_name),
            school_name: (school_name ? school_name : ''),
            inep_code : (inep ? inep : '')
        })
        toggleStepper(false, false, true, false)
    }

    const handleParteTres = (phone, cpf) => {
        setRegisterInformation({...registerInformation,
            teacher_cpf: (phone ? phone : ''),
            school_phone: (cpf ? cpf : ''),
        })
        handleModal();
    }

    const handleCancelar = () => {
        props.history.push('/perfil/atualizacoes')
    }

    const handleFinalSubmit = () => {
        //adicionar headers de accessToken
        axios.post( `${apiUrl}/users/teacher_request`, {
            city : registerInformation.school_city.name,
            cpf : registerInformation.teacher_cpf,
            inep_id : registerInformation.inep_code,
            phone : registerInformation.school_phone,
            school : registerInformation.school_name,
            uf : registerInformation.school_uf.name
        },
        { headers : {
            'Access-Token': sessionStorage.getItem('@portalmec/accessToken'),
            'Client': sessionStorage.getItem('@portalmec/clientToken'),
            'Uid': sessionStorage.getItem('@portalmec/uid')
        }}
        )
        .then( (response) => {
            toggleModal()
            toggleStepper(false, false, false, true)
        }, (error) => console.log('deu erro')
    )
    }

    return (
        <>
        {
            state.userAgreedToPublicationTerms?
            (
                [
                    <>
                        <ModalConfirmarProfessor open={modalOpen} handleClose={handleModal}
                         info={registerInformation} confirmar = {() => {handleFinalSubmit()}}
                         cancelar = {() => {toggleModal()}}
                         />
                        <div style={{backgroundColor:"#f4f4f4", color:"#666"}}>
                            <div style={{display: "flex", justifyContent:"center", paddingTop:"5vh", paddingBottom:"5vh"}}>
                                <Paper elevation={3} style= {{width:"max-content"}}>
                                    <div style={{paddingRight:"15px", paddingLeft:"15px"}}>
                                        {stepper[0].selected &&
                                            <PartOne stepper={stepper} handleBuscar={handleBuscarParteUm}
                                                handleCancelar={handleCancelar}
                                            />
                                        }
                                        {stepper[1].selected &&
                                            <PartTwo stepper={stepper}
                                            info={registerInformation} goBack={toggleStepper}
                                            handleCancelar={handleCancelar} handleBuscar={handleBuscarParteDois}
                                            />
                                        }
                                        {stepper[2].selected &&
                                            <PartThree stepper={stepper} goBack={toggleStepper}
                                            handleCancelar={handleCancelar} info={registerInformation}
                                            handleSubmit={handleParteTres}
                                            />
                                        }
                                        {
                                            stepper[3].selected &&
                                            <SuccessfulRequest email={state.currentUser.email}/>
                                        }
                                    </div>
                                </Paper>
                            </div>
                        </div>
                    </>
                ]
            )
            :
            (
                <>
                {redirect()}
                </>
            )
        }
        </>
    )
}

const ContainerDiv = styled.div`
    .card {
        box-shadow : 0 0 5px 0 rgba(0,0,0,.25);
        background-color :#fff;
        text-align : start;
        margin-left : auto;
        margin-right : auto;
    }

    .part-one {
        max-width : 570px;
    }

    .container {
        padding-right : 15px;
        padding-left : 15px;
    }

    .content {
        margin-top : 16px;
        margin-bottom : 16px;
        margin-right : 10%;
        margin-left : 10%;
    }

    h4 {
        font-family : Roboto;
        font-style : normal;
        font-weight : 300;
        line-height : 36px;
        font-size : 26px;
        margin-top : 20px;
    }
`
