/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/
import React, {useState, useContext}  from 'react';
import styled from 'styled-components'
import {device} from '../Components/device.js'
import { Store } from '../Store.js';
import { Button } from '@material-ui/core';
import Card from '@material-ui/core/Card';
import CardActions from '@material-ui/core/CardActions';
import LabeledCheckbox from "../Components/Checkbox.js"
import TermsPageContent from '../Components/TermsPageContent.js'

const CardStyled = styled(Card)`
    box-sizing : border-box;
    background-color : white;
    max-width: 1700px;
    padding-top: 52px;
    margin-left:7em;
    @media ${device.mobileM} {
        width : 100%;
        height : 100%;
    }
 `

const Styledspan = styled.span`
    font-family: 'Roboto', sans serif;
    font-style: normal;
    font-weight: 500;
    line-height: 22px;
    font-size: 15px;
    letter-spacing: .01em;
`
const StyledSpanContinuar = styled.span`
    font-family: 'Roboto', sans serif;
    font-style: normal;
    font-weight: 500;
    line-height: 22px;
    font-size: 15px;
    letter-spacing: .01em;
    color: #fff;
`

const Styledhr = styled.hr`
    color: #dadada;
`

export default function TermsContainer (props) {
        const {state, dispatch} = useContext(Store)
        const [checked, setChecked] = useState(false);
        const [unavailableButton, setButtonAvailability] = useState(true);

        const handleChecked = e => {
            setChecked(e.target.checked);
            setButtonAvailability(!unavailableButton);
        }

        const handleAgreement = () => {

            dispatch( {
                type: 'USER_AGREED_TO_PUBLICATION_TERMS',
                userAgreement: true
            })

            if (props.location.state.redirectedFromModal) {
                props.history.push('/professor')
            }else {
                props.history.push('/permission')
                window.scrollTo(0, 0)
            }
        }

        return (
                <div style={{paddingTop:"5vh", paddingBottom:"5vh", backgroundColor :"#f4f4f4"}}>
                <div>
                <CardStyled variant="outlined">
                    <TermsPageContent/>
                    <Styledhr/>
                    <CardActions style={{justifyContent:"center", padding:"25px"}}>
                        <div>
                            <div style={{fontSize:"14px"}}>
                                <LabeledCheckbox label={<Styledspan>Li e concordo com os termos de uso da Plataforma Integrada de RED do MEC</Styledspan>} handleChange={handleChecked}/>
                                <div style={{marginLeft:"1em", paddingLeft:"16px", color:"#a0a0a0", justifyContent:"center",display:"flex"}}>
                                    <Button disabled = {unavailableButton}
                                        style={ unavailableButton ? {backgroundColor:"#e9e9e9"} : {backgroundColor:"#00bcd4"}}
                                        onClick={handleAgreement}
                                    >
                                        <StyledSpanContinuar  style={unavailableButton ? {color:"#666666"} : {}}>
                                        Continuar
                                        </StyledSpanContinuar>
                                    </Button>
                                    <Button style={{marginLeft:"45px", backgroundColor:"#e9e9e9"}}>
                                        <Styledspan style={{color:"rgb(102, 102, 102)"}}>
                                        Cancelar
                                        </Styledspan>
                                    </Button>
                                </div>
                            </div>
                        </div>
                    </CardActions>
                    </CardStyled>
                </div>
            </div>
        )
}
